export default class Connections {
    connections = new Map();
    disconnect(object) {
        for (const id of this.connections.get(object) ?? []) {
            object.disconnect(id);
        }
    }
    disconnect_all() {
        for (const [obj, ids] of this.connections.entries()) {
            for (const id of ids) {
                obj.disconnect(id);
            }
        }
    }
    with(object, callback) {
        const connector = new ObjectConnector(object, this.connections);
        if (callback) {
            callback(connector);
        }
        return connector;
    }
}
class ObjectConnector {
    object;
    connections;
    constructor(object, store) {
        this.object = object;
        this.connections = store.get(object) ?? [];
        store.set(this.object, this.connections);
    }
    // biome-ignore lint/suspicious/noExplicitAny: any specified at GObject.Object.connect
    connect(id, callback) {
        const connection = this.object.connect(id, callback);
        this.connections.push(connection);
        return connection;
    }
    // biome-ignore lint/suspicious/noExplicitAny: any specified at GObject.Object.connect
    connect_after(id, callback) {
        const connection = this.object.connect_after(id, callback);
        this.connections.push(connection);
        return connection;
    }
}
